<?php
/*
 * Plugin Name: Indent Lists Button
 * Version: 0.1.2
 * Plugin URI: http://www.elisewebredactie.nl/indent-lists-button
 * Author: Klaas van der Linden
 * Author URI: http://www.culturalservices.nl/
 * Text Domain: indent-lists-button
 * Domain Path: /languages
 * Description: Indent all lists! Once activated, an "Indent List" button appears in the regular WordPress editor.
 */
// Direct access to this file is not permitted
if (! defined ( 'ABSPATH' ))
	exit ();

define ( "ILI_URL", plugin_dir_url ( __FILE__ ) );
function ili_load_plugin_textdomain() {
	load_plugin_textdomain ( 'indent-lists-button', FALSE, basename ( dirname ( __FILE__ ) ) . '/languages/' );
}
add_action ( 'plugins_loaded', 'ili_load_plugin_textdomain' );
// Add new buttons and add the padding:40px-stylesheet to the wordpress editor iframe.
add_action ( 'init', 'ili_init' );
function ili_init() {
	add_filter ( "mce_external_plugins", "ili_register_mce_plugin" );
	add_filter ( 'mce_buttons_2', 'ili_add_button' );
	add_editor_style ( ILI_URL . "css/ili.css" );
}

// Register a new tinymce external plugin at wordpress.
function ili_register_mce_plugin($plugin_array) {
	$plugin_array ['ili_mce_plugin'] = ILI_URL . 'js/mce-plugin.js';
	return $plugin_array;
}

// Tell wordpress to add a button to its tinymce editor, the details of which are contained in the tinymce external plugin 'ili_mce_plugin' registered earlier
function ili_add_button($buttons) {
	if (in_array ( 'indent', $buttons )) {
		$new_buttons = array ();
		foreach ( $buttons as $button ) {
			$new_buttons [] = $button;
			if ($button == 'indent') {
				$new_buttons [] = 'the_ili_button';
			}
		}
		$buttons = $new_buttons;
	} else {
		array_push ( $buttons, 'the_ili_button' );
	}
	return $buttons;
}

// Add padding:40px to frontend lists having class 'ili-indent'.
add_action ( 'wp_enqueue_scripts', 'ili_frontend_css' );
function ili_frontend_css() {
	wp_enqueue_style ( "ili-frontend-css", ILI_URL . "css/ili.css" );
}

// Add the styling for the icon in the wordpress editor.
add_action ( 'admin_enqueue_scripts', 'ili_icon_css' );
function ili_icon_css() {
	wp_enqueue_style ( 'ili-icon-css', ILI_URL . 'css/admin/ili-admin.css' );
}

// Add a javascript object in the header; to be used by mce-plugin.js
foreach ( array('post.php','post-new.php') as $hook ) {
	add_action( "admin_head-$hook", 'ili_admin_head' );
}
function ili_admin_head() {
	/* translators: this is the tooltip when hovering the Indent Lists button */
	$title = esc_html__('Indent List', 'indent-lists-button');
	$data = get_plugin_data(__FILE__,false,true);
	?>
	<script type='text/javascript'>
	var iliGlob = {
	    'title': '<?php echo $title ?>',
	    'version': '<?php echo $data['Version']; ?>',
	    'pluginURI': '<?php echo $data['PluginURI']; ?>',
	    'name': '<?php echo $data['Name']; ?>',
	};
	</script>
    <?php
}